from setuptools import setup, find_packages

setup(
    name='openai_assistant',
    version='0.1.5',
    packages=find_packages(),
    url='',
    license='MIT',
    author='Xiaobocute',
    author_email='Business@xiaobo.tw',
    description='',
    install_requires=[

    ],
)
